# JSON Classes Sanic
JSON Classes integration with Sanic.

## Prerequisites

To use this package, you should have `jsonclasses` and `sanic` installed.

## Installation

Install `jsonclasses-sanic` with `pip`.

```sh
pip install jsonclasses-sanic
```

## Documentation

Read on bla bla bla.

## License

[MIT License](https://github.com/WiosoftCrafts/jsonclasses-sanic/blob/master/LICENSE)
